@@ -1,10 +1,23 @@
 package Aspect::Modular;
 
+# $Id: Modular.pm,v 1.3 2002/07/31 21:29:16 marcelgr Exp $
+#
+# $Log: Modular.pm,v $
+# Revision 1.3  2002/07/31 21:29:16  marcelgr
+# changed version number to 0.08
+#
+# Revision 1.2  2002/07/31 21:03:13  marcelgr
+# changed e-mail address; other changes for version 0.08
+#
+# Revision 1.1.1.1  2002/06/13 07:17:54  marcelgr
+# initial import
+#
+
 use Class::MethodMaker
     new_with_init => 'new',
     list          => 'handlers';
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 sub init {
 	my $self = shift;
@@ -151,11 +164,11 @@ author.
 
 =head1 AUTHOR
 
-Marcel GrE<uuml>nauer <marcel.gruenauer@chello.at>
+Marcel GrE<uuml>nauer <marcel@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright 2001 Marcel GrE<uuml>nauer. All rights reserved.
+Copyright 2001-2002 Marcel GrE<uuml>nauer. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
